summaryrefslogtreecommitdiff
path: root/automation/source/testtool/objtest.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'automation/source/testtool/objtest.hxx')
-rw-r--r--automation/source/testtool/objtest.hxx107
1 files changed, 53 insertions, 54 deletions
diff --git a/automation/source/testtool/objtest.hxx b/automation/source/testtool/objtest.hxx
index a7297ad79a32..5c95fea3dd05 100644
--- a/automation/source/testtool/objtest.hxx
+++ b/automation/source/testtool/objtest.hxx
@@ -36,7 +36,6 @@
#include <testtool.hxx>
#include "cmdstrm.hxx"
#include <basic/basicrt.hxx>
-#include <vcl/smartid.hxx>
#include "httprequest.hxx"
#include <map>
@@ -107,7 +106,7 @@ class ControlData
{
public:
String Kurzname;
- SmartId aUId;
+ rtl::OString aUId;
};
DBG_NAMEEX( ControlItem )
@@ -119,34 +118,34 @@ private:
public:
ControlData *pData;
- ControlItem( const char *Name, SmartId aUIdP );
- ControlItem( const String &Name, SmartId aUIdP );
+ ControlItem( const char *Name, rtl::OString aUIdP );
+ ControlItem( const String &Name, rtl::OString aUIdP );
ControlItem( ControlData *pDataP );
virtual ~ControlItem() {
DBG_DTOR(ControlItem,0);
delete pData;
}
- virtual BOOL operator < (const ControlItem &rPar)=0;
- virtual BOOL operator == (const ControlItem &rPar)=0;
+ virtual sal_Bool operator < (const ControlItem &rPar)=0;
+ virtual sal_Bool operator == (const ControlItem &rPar)=0;
};
SV_DECL_PTRARR_SORT_DEL(CNames, ControlItem*, 50, 10)
#define MK_SON_ACCESS( ClassName )\
- BOOL SonInsert( const ClassName *pNewEntry ) { const ControlItem *pItem = pNewEntry; return pSons->Insert( pItem ); }\
- BOOL SonSeek_Entry( const ClassName *pSearchEntry, USHORT *nRes = NULL) { return pSons->Seek_Entry( pSearchEntry, nRes ); }\
- ClassName* SonGetObject( USHORT nNr ) { return (ClassName*)pSons->GetObject( nNr ); }
+ sal_Bool SonInsert( const ClassName *pNewEntry ) { const ControlItem *pItem = pNewEntry; return pSons->Insert( pItem ); }\
+ sal_Bool SonSeek_Entry( const ClassName *pSearchEntry, sal_uInt16 *nRes = NULL) { return pSons->Seek_Entry( pSearchEntry, nRes ); }\
+ ClassName* SonGetObject( sal_uInt16 nNr ) { return (ClassName*)pSons->GetObject( nNr ); }
class ControlSon
{
protected:
- CNames *pSons; // um sicherzustelle, da nur Shne des richtien Type reinkommen
+ CNames *pSons; // um sicherzustelle, da� nur S�hne des richtien Type reinkommen
public:
ControlSon() : pSons( NULL ) {};
~ControlSon();
- USHORT Son_Count() { return pSons->Count(); }
+ sal_uInt16 Son_Count() { return pSons->Count(); }
void Sons( CNames *pNewSons ) { pSons = pNewSons; }
CNames*& GetSons() { return pSons; }
};
@@ -154,21 +153,21 @@ public:
class ControlItemSon : public ControlItem, public ControlSon
{
public:
- ControlItemSon(const char *Name, SmartId aUIdP )
+ ControlItemSon(const char *Name, rtl::OString aUIdP )
: ControlItem( Name, aUIdP ) {}
- ControlItemSon(const String &Name, SmartId aUIdP );
+ ControlItemSon(const String &Name, rtl::OString aUIdP );
};
class ControlDef : public ControlItemSon
{
public:
- ControlDef(const char *Name, SmartId aUIdP )
+ ControlDef(const char *Name, rtl::OString aUIdP )
: ControlItemSon( Name, aUIdP ) {DBG_CTOR(ControlDef,0);}
- ControlDef(const String &Name, SmartId aUIdP );
- ControlDef(const String &aOldName, const String &aNewName, ControlDef *pOriginal, BOOL bWithSons = FALSE );
+ ControlDef(const String &Name, rtl::OString aUIdP );
+ ControlDef(const String &aOldName, const String &aNewName, ControlDef *pOriginal, sal_Bool bWithSons = sal_False );
~ControlDef() {DBG_DTOR(ControlDef,0);}
- virtual BOOL operator < (const ControlItem &rPar);
- virtual BOOL operator == (const ControlItem &rPar);
+ virtual sal_Bool operator < (const ControlItem &rPar);
+ virtual sal_Bool operator == (const ControlItem &rPar);
void Write( SvStream &aStream );
MK_SON_ACCESS( ControlDef )
};
@@ -176,33 +175,33 @@ public:
class ControlItemUId : public ControlItem
{
public:
- ControlItemUId(String Name, SmartId aUIdP)
+ ControlItemUId(String Name, rtl::OString aUIdP)
: ControlItem( Name, aUIdP){}
- virtual BOOL operator < (const ControlItem &rPar);
- virtual BOOL operator == (const ControlItem &rPar);
+ virtual sal_Bool operator < (const ControlItem &rPar);
+ virtual sal_Bool operator == (const ControlItem &rPar);
};
class ControlItemUIdSon : public ControlItemUId, public ControlSon
{
public:
- ControlItemUIdSon(String Name, SmartId aUIdP) : ControlItemUId( Name, aUIdP) {}
+ ControlItemUIdSon(String Name, rtl::OString aUIdP) : ControlItemUId( Name, aUIdP) {}
MK_SON_ACCESS( ControlItemUId )
};
class ReverseName : public ControlItemUId
{
public:
- ULONG LastSequence;
+ sal_uLong LastSequence;
- ReverseName(String Name, SmartId aUIdP, ULONG nSeq) : ControlItemUId( Name, aUIdP), LastSequence(nSeq) {}
+ ReverseName(String Name, rtl::OString aUIdP, sal_uLong nSeq) : ControlItemUId( Name, aUIdP), LastSequence(nSeq) {}
};
class CRevNames: public CNames
{
public:
- void Insert( String aName, SmartId aUId, ULONG nSeq );
- String GetName( SmartId aUId );
- void Invalidate ( ULONG nSeq );
+ void Insert( String aName, rtl::OString aUId, sal_uLong nSeq );
+ String GetName( rtl::OString aUId );
+ void Invalidate ( sal_uLong nSeq );
};
@@ -210,7 +209,7 @@ class SbxTransportMethod: public SbxMethod
{
public:
SbxTransportMethod( SbxDataType );
- ULONG nValue;
+ sal_uLong nValue;
String aUnoSlot;
};
SV_DECL_IMPL_REF(SbxTransportMethod);
@@ -235,10 +234,10 @@ typedef std::map< String, String > Environment;
class ImplTestToolObj
{
public:
- String ProgParam; // Parameter der zu Testenden APP; Gesetzt ber Start
+ String ProgParam; // Parameter der zu Testenden APP; Gesetzt �ber Start
- DirEntry aFileBase; // Grundpfad fr die *.sid und *.win Dateien (Aus Configdatei)
- DirEntry aLogFileBase; // Grundpfad fr die *.res Dateien (Aus Configdatei)
+ DirEntry aFileBase; // Grundpfad f�r die *.sid und *.win Dateien (Aus Configdatei)
+ DirEntry aLogFileBase; // Grundpfad f�r die *.res Dateien (Aus Configdatei)
DirEntry aHIDDir; // Verzeichnis, in dem die hid.lst gesucht wird
SbxTransportMethodRef pNextReturn; // Verweis auf die Var, die den Returnwert aufnimmt.
@@ -246,48 +245,48 @@ public:
ControlsRef pControlsObj; // Jeweiliges Objekt, an dem Methoden aufgerufen weden.
#define VAR_POOL_SIZE 8
- SbxTransportMethodRef pMyVars[VAR_POOL_SIZE]; // Falls in Ausdrcken mehrere verwendet werden
+ SbxTransportMethodRef pMyVars[VAR_POOL_SIZE]; // Falls in Ausdr�cken mehrere verwendet werden
Time aServerTimeout;
// Profiling Datenfelder
- ULONG LocalStarttime;
- USHORT nNumBorders;
- ULONG naValBorders[4];
- ULONG naNumEntries[5];
- ULONG naRemoteTime[5];
- ULONG naLocalTime[5];
-
- ULONG nMinRemoteCommandDelay;
- ULONG nMaxRemoteCommandDelay;
- BOOL bDoRemoteCommandDelay;
-
- BOOL bLnaguageExtensionLoaded; // Wurde ber 'use' was geladen? Fr syntax highlighting
+ sal_uLong LocalStarttime;
+ sal_uInt16 nNumBorders;
+ sal_uLong naValBorders[4];
+ sal_uLong naNumEntries[5];
+ sal_uLong naRemoteTime[5];
+ sal_uLong naLocalTime[5];
+
+ sal_uLong nMinRemoteCommandDelay;
+ sal_uLong nMaxRemoteCommandDelay;
+ sal_Bool bDoRemoteCommandDelay;
+
+ sal_Bool bLnaguageExtensionLoaded; // Wurde �ber 'use' was geladen? F�r syntax highlighting
SfxBroadcaster *pTTSfxBroadcaster;
- ULONG nErrorCount;
- ULONG nWarningCount;
- ULONG nQAErrorCount;
- ULONG nIncludeFileWarningCount;
+ sal_uLong nErrorCount;
+ sal_uLong nWarningCount;
+ sal_uLong nQAErrorCount;
+ sal_uLong nIncludeFileWarningCount;
SbxDimArrayRef xErrorList;
SbxDimArrayRef xWarningList;
SbxDimArrayRef xQAErrorList;
SbxDimArrayRef xIncludeFileWarningList;
- BOOL bIsStart; // set tu TRUE while command Start is initiating the communication
+ sal_Bool bIsStart; // set tu sal_True while command Start is initiating the communication
MyBasic* pMyBasic;
String aTestCaseName; // holds name of current TestCase
String aTestCaseFileName; // holds FileName of current TestCase
- USHORT nTestCaseLineNr; // holds Line of current TestCase
+ sal_uInt16 nTestCaseLineNr; // holds Line of current TestCase
- BOOL bEnableQaErrors; // include QA errors in report
- BOOL bDebugFindNoErrors; // suppress generating errors when find of variables is called for variable viewing purposes
+ sal_Bool bEnableQaErrors; // include QA errors in report
+ sal_Bool bDebugFindNoErrors; // suppress generating errors when find of variables is called for variable viewing purposes
- BOOL bStopOnSyntaxError; // catch syntax errors in testcases or not
+ sal_Bool bStopOnSyntaxError; // catch syntax errors in testcases or not
Environment *pChildEnv; // Environment Variables for child Process
@@ -298,7 +297,7 @@ public:
class TTFormat
{
public:
- static String ms2s( ULONG nMilliSeconds );
+ static String ms2s( sal_uLong nMilliSeconds );
};